You are viewing a plain text version of this content. The canonical link for it is here.
Posted to test-commits@perl.apache.org by jo...@apache.org on 2012/05/02 13:14:37 UTC

svn commit: r1332994 - /perl/Apache-Test/trunk/lib/Apache/TestConfigParse.pm

Author: jorton
Date: Wed May  2 11:14:37 2012
New Revision: 1332994

URL: http://svn.apache.org/viewvc?rev=1332994&view=rev
Log:
* lib/Apache/TestConfigParse.pm: Block some more modules which
  prevent test suite running.

Modified:
    perl/Apache-Test/trunk/lib/Apache/TestConfigParse.pm

Modified: perl/Apache-Test/trunk/lib/Apache/TestConfigParse.pm
URL: http://svn.apache.org/viewvc/perl/Apache-Test/trunk/lib/Apache/TestConfigParse.pm?rev=1332994&r1=1332993&r2=1332994&view=diff
==============================================================================
--- perl/Apache-Test/trunk/lib/Apache/TestConfigParse.pm (original)
+++ perl/Apache-Test/trunk/lib/Apache/TestConfigParse.pm Wed May  2 11:14:37 2012
@@ -177,13 +177,15 @@ my %modname_alias = (
     'mod_modperl.c'        => 'mod_perl.c',
 );
 
 #XXX mod_jk requires JkWorkerFile or JkWorker to be configured
 #skip it for now, tomcat has its own test suite anyhow.
 #XXX: mod_casp2.so requires other settings in addition to LoadModule
 #XXX: mod_bwshare.so blocks fast requests that tests are doing
 #XXX: mod_fcgid.so causes https://rt.cpan.org/Public/Bug/Display.html?id=54476
 my @autoconfig_skip_module = qw(mod_jk.c mod_casp2.c mod_bwshare.c
-    mod_fcgid.c);
+    mod_fcgid.c mod_evasive20.c mod_modnss.c mod_rev.c);
 
 # add modules to be not inherited from the existing config.
 # e.g. prevent from LoadModule perl_module to be included twice, when
@@ -177,13 +177,15 @@ my %modname_alias = (
 );
 
-#XXX mod_jk requires JkWorkerFile or JkWorker to be configured
-#skip it for now, tomcat has its own test suite anyhow.
-#XXX: mod_casp2.so requires other settings in addition to LoadModule
-#XXX: mod_bwshare.so blocks fast requests that tests are doing
-#XXX: mod_fcgid.so causes https://rt.cpan.org/Public/Bug/Display.html?id=54476
+# Block modules which inhibit testing:
+# - mod_jk requires JkWorkerFile or JkWorker to be configured
+#   skip it for now, tomcat has its own test suite anyhow.
+# - mod_casp2 requires other settings in addition to LoadModule
+# - mod_bwshare and mod_evasive20 block fast requests that tests are doing
+# - mod_fcgid causes https://rt.cpan.org/Public/Bug/Display.html?id=54476
+# - mod_modnss.c mod_rev.c
 my @autoconfig_skip_module = qw(mod_jk.c mod_casp2.c mod_bwshare.c